@@ -17,12 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-/*
- * general includes for the TEG client
- */
 
-#ifndef __TEGC_CLIENT_H
-#define __TEGC_CLIENT_H
+#pragma once
 
 #include "player.h"
 #include "globals.h"
@@ -35,5 +31,3 @@
 #include "reagrupe.h"
 #include "ejer2.h"
 #include "canje.h"
-
-#endif /* __TEGC_CLIENT_H */
