@@ -25,12 +25,11 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "../common/common.h"
+#include "../common/country.h"
 
-#include "common.h"
-#include "country.h"
+namespace teg::client
+{
 
 /**
  * \brief places one army of the player into country \p p.
@@ -112,6 +111,4 @@ TEG_STATUS fichas_leave(PCOUNTRY p);
  * \p cant, the continent bitfield will be placed in \p conts. */
 void fichas_get_wanted(int *cant, int *conts);
 
-#ifdef __cplusplus
 }
-#endif
