@@ -20,9 +20,8 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::client::callbacks
+{
 
 enum DisconnectReason {
 	/// the client decided to terminate the connection (for example with the
@@ -43,8 +42,6 @@ void disconnect(enum DisconnectReason reason);
 
 void connect_view();
 void gametype_view();
-void colortype_view(char *colores);
+void colortype_view(const int *colores);
 
-#ifdef __cplusplus
 }
-#endif
