@@ -18,11 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TEG_GUI_GNOME_PRIV_H
-#define __TEG_GUI_GNOME_PRIV_H
+#pragma once
 
 #include <gtk/gtk.h>
 
+#include "../../common/common.h"
+
+namespace teg::client::callbacks
+{
+
 enum {
 	DIALOG_ATTACK_TURN,
 	DIALOG_REGROUP_ARMIES,
@@ -30,7 +34,7 @@ enum {
 };
 
 struct _gui_private {
-	BOOLEAN msg_show_colors;
+	bool msg_show_colors;
 	unsigned int status_show;	/* what columns to show in the status window */
 	unsigned int dialog_show;	/* what dialogs to show */
 	int country_i_am;		/* what country i'm pointing */
@@ -42,4 +46,4 @@ extern GSettings *settings;
 
 TEG_STATUS priv_init(void);
 
-#endif /* __TEG_GUI_GNOME_PRIV_H */
+}
