@@ -18,14 +18,23 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef __TEG_GUI_GNOME_SUPPORT_H
-#define __TEG_GUI_GNOME_SUPPORT_H
+#pragma once
+
+#include <filesystem>
+
+#include <glib.h>
+#include <gtk/gtk.h>
+
+namespace teg::client::callbacks
+{
 
 void generic_window_set_parent(GtkWidget * dialog, GtkWindow   * parent);
-char * load_pixmap_file(char *name);
+
+/// Calculate the absolute file path for a given ressource file (in /share/teg)
+std::filesystem::path load_pixmap_file(const char *name);
 void teg_dialog(char* title, char* bigtitle, char* data);
 GtkWidget* teg_dialog_new(char* title, char* bigtitle);
 void teg_dialog_gameover(int numjug, int mission);
 gchar *translate_to_utf8(const gchar *string);
 
-#endif /* __TEG_GUI_GNOME_SUPPORT_H */
+}
