@@ -18,13 +18,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include "../common/scores.h"
 #include "player.h"
 
+namespace teg::client
+{
+
 TEG_STATUS aux_status(PCPLAYER pj, char const *str);
 TEG_STATUS aux_countries(int numjug, const char *str);
 void aux_draw_all_countries();
@@ -34,6 +33,4 @@ TEG_STATUS aux_start_error();
 /*! parse one score */
 TEG_STATUS aux_scores(PSCORES pS, char const *str);
 
-#ifdef __cplusplus
 }
-#endif
