@@ -22,9 +22,8 @@
 
 #include "../common/common.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::client
+{
 
 /**
  * Parses the server response from filsdescriptor \p pf and dispatch the
@@ -35,6 +34,4 @@ extern "C" {
  */
 TEG_STATUS client_recv(int fd);
 
-#ifdef __cplusplus
 }
-#endif
