@@ -22,9 +22,8 @@
 
 #include "../common/common.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::client
+{
 
 /// \brief initialize the client game dataset
 void game_init();
@@ -56,7 +55,7 @@ TEG_STATUS launch_server(int port);
 TEG_STATUS launch_robot(void);
 
 /// Log-like function to display messages above \p level in the GUI
-TEG_STATUS textmsg(int level, char *format, ...);
+TEG_STATUS textmsg(int level, const char *format, ...);
 
 /// Create the .teg directory structure in the users home directory
 TEG_STATUS dirs_create();
@@ -69,6 +68,4 @@ TEG_STATUS dirs_create();
 #define ESTADO_GET() g_game.estado
 #define ESTADO_SET(a) (g_game.estado=(a))
 
-#ifdef __cplusplus
 }
-#endif
