@@ -21,11 +21,10 @@
 #pragma once
 
 #include "client.h"
-#include "common.h"
+#include "../common/common.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::client
+{
 
 /** \addtogroup TransmitProtocoll
  *
@@ -98,6 +97,4 @@ TEG_STATUS out_new_round();
 
 /** \} */
 
-#ifdef __cplusplus
 }
-#endif
