@@ -20,12 +20,17 @@
 
 #pragma once
 
-#include <libxml/parser.h>
-#include "common.h"
+#include <filesystem>
+#include <optional>
+#include <set>
+#include <string>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include <libxml/parser.h>
+
+#include "../common/common.h"
+
+namespace teg::client
+{
 
 #define THEME_CONTINENT_MAX	(30)
 #define THEME_COUNTRY_MAX	(30)
@@ -110,7 +115,7 @@ typedef struct _theme {
 	xmlChar	*dices_ext_y[6];
 	xmlChar	*dices_ext_text_x[2];
 	xmlChar	*dices_ext_text_y[2];
-	xmlChar *dices_file[DICES_CANT];	/**< 6 dices */
+	xmlChar *dices_file[sides_on_the_dice];	/**< 6 dices */
 	xmlChar	*dices_color;
 	xmlChar	*screenshot;
 	int	i_continent;
@@ -144,20 +149,12 @@ typedef struct _ttheme {
 	int	dices_ext_y[6];
 	int	dices_ext_text_x[2];
 	int	dices_ext_text_y[2];
-	char	*dices_file[DICES_CANT];
+	char	*dices_file[sides_on_the_dice];
 	char	*dices_color;
 	char	*screenshot;
 } TTheme, *pTTheme;
 
-/* Theme Info */
-typedef struct _tinfo {
-	struct _tinfo *next;
-	char *name;
-	char *author;
-	char *email;
-	char *version;
-} TInfo, *pTInfo;
-
+using ThemeDirectories = std::set<std::string>;
 
 /// \brief Tries to load the theme named \p name from different directories
 TEG_STATUS theme_load(char *name);
@@ -175,20 +172,15 @@ TEG_STATUS theme_giveme_country(pTCountry pC, int cont, int n);
 TEG_STATUS theme_giveme_theme(pTTheme pT);
 
 /// \brief Return the list of all available themes
-TEG_STATUS theme_enum_themes(pTInfo pTI);
-
-/// \brief Delete the theme list
-void theme_free();
+ThemeDirectories const& theme_enum_themes();
 
 /// \brief Tries to load the theme \p name.
-char * theme_load_file(char *name);
+std::optional<std::filesystem::path> theme_load_file(const char *name);
 
 /// Tries to load the preview image
-char * theme_load_fake_file(char *name, char *theme);
+std::optional<std::filesystem::path> theme_load_fake_file(const char *name, const char *theme);
 
 /**! returns 1 if dices extended are being used */
 int theme_using_extended_dices();
 
-#ifdef __cplusplus
 }
-#endif
