@@ -20,9 +20,7 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include <string>
 
 #include "cont.h"
 
@@ -31,7 +29,7 @@ typedef struct _missions {
 	int	player_number;
 
 	/// The name of the mission
-	char	*name;
+	char const *name;
 
 	/// number of countries to conquer on each continent
 	int	continents[CONTINENTE_LAST];
@@ -55,8 +53,4 @@ extern MISSIONS g_missions[];
 int missions_cant();
 
 /* return the name of a mission (translated) */
-char const* missions_get_name(int number);
-
-#ifdef __cplusplus
-}
-#endif
+std::string missions_get_name(int number);
