@@ -21,8 +21,7 @@
  *	Definicion del protocolo
  */
 
-#ifndef __TEG_PROTOCOL_H
-#define __TEG_PROTOCOL_H
+#pragma once
 
 #define PROTOCOL_HIVER	6
 #define PROTOCOL_LOVER	0
@@ -32,9 +31,7 @@
 
 /* tokens */
 #define TOKEN_CVERSION		"client_version"
-#define TOKEN_DISCON		"disconnect"
 #define TOKEN_EXIT		"exit"
-#define TOKEN_GAMEOVER		"game_over"
 #define TOKEN_HELP		"help"
 #define TOKEN_LOST		"loser"
 #define TOKEN_MESSAGE		"msg"
@@ -46,24 +43,19 @@
 #define TOKEN_REM		"*"
 #define TOKEN_ROBOT		"quiero_jugar_con_un_robot"
 #define TOKEN_SCORES		"scores"
-#define TOKEN_STATS		"stats"
 #define TOKEN_SERVERFULL	"el_servidor_esta_lleno"
 #define TOKEN_GAMEINPROGRESS	"game_in_progress"
 #define TOKEN_SVERSION		"server_version"
-#define TOKEN_ALONE		"solo_a_ningun_lado"
 #define TOKEN_START		"start"
 #define TOKEN_STATUS		"status"
 #define TOKEN_TEST		"eva_test"
 #define	TOKEN_TURNO		"turno"
-#define	TOKEN_WAIT		"wait"
 #define	TOKEN_WINNER		"winner"
 #define TOKEN_ERROR		"error"
-#define TOKEN_OK		"ok"
 #define TOKEN_COUNTRIES		"paises"
 #define TOKEN_FICHAS		"fichas"
 #define TOKEN_FICHAS2		"fichas2"
 #define TOKEN_FICHASC		"fichasc"
-#define TOKEN_FICHAS3		"fichas3"
 #define TOKEN_ATAQUE		"ataque"
 #define TOKEN_TROPAS		"tropas"
 #define TOKEN_COUNTRY		"pais"
@@ -75,17 +67,17 @@
 #define TOKEN_MODALIDAD		"modalidad"
 #define TOKEN_MISSION		"mission"
 #define TOKEN_SET		"set"
-#define TOKEN_VIEW		"view"
 #define TOKEN_COLOR		"color"
-#define TOKEN_SAVE		"save"
 #define TOKEN_LOQUE		"que_tengo_que_hacer"
-#define TOKEN_PACTO_REQUEST	"pacto_request"
-#define TOKEN_PACTO_REPLY	"pacto_reply"
 #define TOKEN_SURRENDER		"soy_cobarde"
-#define TOKEN_KICK		"kick"
 #define TOKEN_ENUM_CARDS	"enum_cards"
 #define TOKEN_NEW_ROUND		"new_round"
-#define TOKEN_METASERVER	"metaserver"
+
+// only server console
+#define TOKEN_STATS		"stats"
+#define TOKEN_VIEW		"view"
+#define TOKEN_SAVE		"save"
+#define TOKEN_KICK		"kick"
 
 /* options */
 #define OPTION_CONQWORLD	"conquer_world"
@@ -96,10 +88,5 @@
 #define OPTION_FOG_OF_WAR	"fog_of_war"
 
 /* metaserver */
-#define OPTION_META_LIST	"list"
+#define TOKEN_METASERVER	"metaserver"
 #define OPTION_META_ON		"on"
-#define OPTION_META_OFF		"off"
-#define OPTION_META_ADDRESS	"address"
-#define OPTION_META_STATUS	"status"
-
-#endif /* __TEG_PROTOCOL_H */
