@@ -18,19 +18,16 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef TEG_TEGDEBUG_H
-#define TEG_TEGDEBUG_H
+#pragma once
 
 #include <stdio.h>
 
 #define TEGDEBUG
 
 #ifdef TEGDEBUG
-#	define PDEBUG(format, ...) fprintf(stderr, "%s:%d(%s)" format, \
-	                               __FILE__, __LINE__, __PRETTY_FUNCTION__ \
-	                               __VA_OPT__(, __VA_ARGS__))
+#    define PDEBUG(format, ...) fprintf(stderr, "%s:%d(%s)" format, \
+                                       __FILE__, __LINE__, __PRETTY_FUNCTION__, \
+                                       ## __VA_ARGS__)
 #else
-#	define PDEBUG(a)
+#   define PDEBUG(...)
 #endif
-
-#endif /* __TEG_TEGDEBUG_H */
