@@ -21,9 +21,8 @@
 
 #include "../common/common.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::robot
+{
 
 /// Place the regular armies
 TEG_STATUS ai_fichas(int cant);
@@ -34,6 +33,4 @@ TEG_STATUS ai_fichasc(int cant, int conts);
 /// Calls all the strategies of the robots to place armies
 TEG_STATUS ai_fichas_calc_puntaje(int p);
 
-#ifdef __cplusplus
 }
-#endif
