@@ -20,13 +20,10 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::robot
+{
 
 /// Select a random player name.
 char *ai_fetch_a_name();
 
-#ifdef __cplusplus
 }
-#endif
