@@ -20,9 +20,8 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::server
+{
 
 /**
  * This function takes place at the beginning of a game, and randomly assign
@@ -30,6 +29,4 @@ extern "C" {
  */
 void countries_repartir();
 
-#ifdef __cplusplus
 }
-#endif
