@@ -20,9 +20,10 @@
 
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#include "player.h"
+
+namespace teg::server
+{
 
 /**! initialize the game */
 void game_init();
@@ -31,10 +32,10 @@ void game_init();
 void game_new();
 
 /**! called when a game in finish */
-void game_end();
+void game_end(PSPLAYER winner);
 
 /**! when the game is over */
-BOOLEAN game_is_finished(void);
+bool game_is_finished(void);
 
 void server_init();
 
@@ -44,6 +45,4 @@ void fd_remove(int fd);
 /**! adds a new fd to the list of fd */
 void fd_add(int fd);
 
-#ifdef __cplusplus
 }
-#endif
