@@ -25,9 +25,8 @@
 #include "../common/common.h"
 #include "player.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::server
+{
 
 /// \brief Does player pJ accomplished his secret mission ?
 TEG_STATUS mission_chequear(PSPLAYER pJ);
@@ -44,6 +43,4 @@ TEG_STATUS mission_set(bool a);
 /// \brief Enables/Disables playing with common secret mission
 TEG_STATUS mission_common_mission(bool a);
 
-#ifdef __cplusplus
 }
-#endif
