@@ -22,9 +22,8 @@
 
 #include "../common/common.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::server
+{
 
 /// \brief Parses a game option received from a client
 TEG_STATUS option_parse(int fd, char *str);
@@ -32,6 +31,4 @@ TEG_STATUS option_parse(int fd, char *str);
 /// \brief Print the current game options on the console
 TEG_STATUS option_view(int fd, char *str);
 
-#ifdef __cplusplus
 }
-#endif
