@@ -19,13 +19,10 @@
  */
 #pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+namespace teg::server
+{
 
 /// \brief send a message to all connected players.
-void netall_printf(char *format, ...);
+void netall_printf(char const *format, ...);
 
-#ifdef __cplusplus
 }
-#endif
